tuplettools.leaf_to_tuplet_with_n_notes_of_equal_written_duration
=================================================================

.. autofunction:: abjad.tools.tuplettools.leaf_to_tuplet_with_n_notes_of_equal_written_duration.leaf_to_tuplet_with_n_notes_of_equal_written_duration
   :noindex:
